@@ -7,6 +7,7 @@
 import inspect
 import json
 import time
+import types
 from datetime import datetime
 from decimal import Decimal
 from typing import Optional, Awaitable, Any
@@ -38,6 +39,18 @@ class BaseHandler(RequestHandler):
         self.end_time = int(round(time.time() * 1000))
         self.original = False
         super().__init__(application, request, **kwargs)
+        self.command_map = {}
+        methods = self.methods()
+        for i in range(len(methods)):
+            method = getattr(self, methods[i])
+            if getattr(method, "__http_method__", None):
+                self.command_map[method.__name__] = method
+
+    def methods(self):
+        return (list(filter(
+            lambda m: not m.startswith("__") and not m.startswith("_") and callable(getattr(self, m)) and
+                      type(getattr(self, m, None)) == types.MethodType,
+            self.__dir__())))
 
     async def get(self):
         """
